pub enum InternalRenderingError {
Rendering(String),
LimitExceeded(ImplementationLimit),
InvalidTransform,
CircularReference(Node<NodeData>),
IdNotFound,
InvalidId(String),
OutOfMemory(String),
Cancelled,
}Expand description
Errors that can happen while rendering or measuring an SVG document.
This is the internal version of crate::api::RenderingError; they are the same
except that this one has an InvalidTransform variant which is only propagated
internally. It is caught during the drawing process, and the element in question
is simply not drawn, more or less per https://www.w3.org/TR/css-transforms-1/#transform-function-lists
“If a transform function causes the current transformation matrix of an object to be non-invertible, the object and its content do not get displayed.”
Variants
Rendering(String)
An error from the rendering backend.
LimitExceeded(ImplementationLimit)
A particular implementation-defined limit was exceeded.
InvalidTransform
A non-invertible transform was generated.
This should not be a fatal error; we should catch it and just not render the problematic element.
CircularReference(Node<NodeData>)
IdNotFound
Tried to reference an SVG element that does not exist.
InvalidId(String)
Tried to reference an SVG element from a fragment identifier that is incorrect.
OutOfMemory(String)
Not enough memory was available for rendering.
Cancelled
The rendering was interrupted via a [gio::Cancellable].