pub type ParseError<'i> = ParseError<'i, ValueErrorKind>;Expand description
A short-lived error.
The lifetime of the error is the same as the cssparser::ParserInput that
was used to create a cssparser::Parser. That is, it is the lifetime of
the string data that is being parsed.
The code flow will sometimes require preserving this error as a long-lived struct;
see the impl<'i, O> AttributeResultExt<O> for Result<O, ParseError<'i>> for that
purpose.
Aliased Type
pub struct ParseError<'i> {
pub kind: ParseErrorKind<'i, ValueErrorKind>,
pub location: SourceLocation,
}Fields
kind: ParseErrorKind<'i, ValueErrorKind>Details of this error
location: SourceLocationLocation where this error occurred